package de.ozgcloud.eingang.formcycle;

import java.util.Collections;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.eingang.common.formdata.ServiceKonto;
import de.ozgcloud.eingang.common.formdata.ServiceKonto.PostfachAddress;
import de.ozgcloud.eingang.common.formdata.StringBasedIdentifier;

@Mapper(collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, unmappedTargetPolicy = ReportingPolicy.WARN)
interface FormCycleServiceKontoMapper {

	@Mapping(target = "postfachAddress", ignore = true)
	@Mapping(target = "postfachAddresses", expression = "java(fromGrpcPostfachAddresses(serviceKonto))")
	ServiceKonto fromGrpc(FormCycleServiceKonto serviceKonto);

	default String fromString(String str) {
		return StringUtils.trimToNull(str);
	}

	default List<PostfachAddress> fromGrpcPostfachAddresses(FormCycleServiceKonto serviceKonto) {
		return serviceKonto.hasAddress() ? List.of(fromGrpc(serviceKonto.getAddress())) : Collections.emptyList();
	}

	@Mapping(target = "type", ignore = true)
	@Mapping(target = "identifier", expression = "java(buildIdentifier(postfachAddress.getIdentifier()))")
	PostfachAddress fromGrpc(FormCyclePostfachAddress postfachAddress);

	default StringBasedIdentifier buildIdentifier(String identifier) {
		return StringBasedIdentifier.builder().postfachId(identifier).build();
	}
}