package de.ozgcloud.eingang.xdomea;

import static de.ozgcloud.eingang.common.formdata.IncomingFileGroupTestFactory.*;

import java.util.UUID;
import java.util.stream.Stream;

import de.ozgcloud.eingang.common.formdata.IncomingFileGroup;
import de.ozgcloud.eingang.common.formdata.IncomingFileTestFactory;

public class XdomeaMessageDataTestFactory {
	public static XdomeaMessageData create(boolean useUuidPrefix) {
		return createBuilder(useUuidPrefix).build();
	}

	public static XdomeaMessageData.XdomeaMessageDataBuilder createBuilder(boolean useUuidPrefix) {
		var incomingFiles = Stream.of(
						XDOMEA_XML_NAME,
						REPR_XML_NAME,
						REPR_PDF_NAME,
						ATTATCHMENT_XML_NAME,
						ATTATCHMENT_PNG_NAME,
						ATTATCHMENT_PDF_NAME
				)
				.map(name -> useUuidPrefix ? withUUIDPrefix(name) : name)
				.map(name -> IncomingFileTestFactory.createBuilder().name(name).build())
				.toList();

		return XdomeaMessageData.builder()
				.metadataFile(incomingFiles.getFirst())
				.representations(incomingFiles.subList(1, 3))
				.attachments(incomingFiles.subList(3, 6).stream()
						.map(incomingFile -> IncomingFileGroup.builder()
								.name("group-name")
								.file(incomingFile)
								.build())
						.toList()
				);
	}

	private static String withUUIDPrefix(String name) {
		return UUID.randomUUID() + "_" + name;
	}

}
